'use strict'

const fs = require('fs')
const path = require('path')
const gql = require('graphql-tag')
const EasyGraphQLTester = require('../lib')

const testSchema = fs.readFileSync(path.join(__dirname, 'schema.gql'), 'utf8')

const schema = `
  type Query {
    node(id: ID!): Node
  }

  type Issue implements Node {
    author: Actor
    id: ID!
  }

  interface Actor {
    login: String!
  }

  interface Node {
    id: ID!
  }
`


const tester = new EasyGraphQLTester(testSchema)

const query = `
  query trialQuery {
    node(id: "MDU6SXNzdWUzOTg3OTg1MjE=") {
      id
      ... on Issue {
        author {
          login
        }
      }
    }
  }
`

const query1 = `
query ConnectedApps($uuid: String!) {
  organization(uuid: $uuid) {
    id
    name
    projects {
      nodes {
        id
        name
        githubIntegration {
          repository {
            owner {
              avatarUrl
            }
          }
        }
      }
    }
  }
}
`

const mutation = `
  mutation CREATE_USER($input: UserInput!) {
    createUser(input: $input) {
      username
    }
  }
`

console.log(tester.mock({
  query: query1,
  variables: {
    uuid: '1'
  }
}).data.organization.projects);